;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "projectile" "3.2.1"
  "Manage and navigate projects in Emacs easily."
  '((emacs  "28.1")
    (compat "30"))
  :url "https://github.com/bbatsov/projectile"
  :commit "8ac2834f1f70af977f17944c7968c72ea46bf62c"
  :revdesc "8ac2834f1f70"
  :keywords '("project" "convenience")
  :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
